@@ -14,6 +14,7 @@ Usage::
         CustomerGatewayAvailableWaiter,
         DescribeAddressTransfersPaginator,
         DescribeAddressesAttributePaginator,
+        DescribeAwsNetworkPerformanceMetricSubscriptionsPaginator,
         DescribeByoipCidrsPaginator,
         DescribeCapacityReservationFleetsPaginator,
         DescribeCapacityReservationsPaginator,
@@ -103,6 +104,11 @@ Usage::
         DescribeTransitGatewayVpcAttachmentsPaginator,
         DescribeTransitGatewaysPaginator,
         DescribeTrunkInterfaceAssociationsPaginator,
+        DescribeVerifiedAccessEndpointsPaginator,
+        DescribeVerifiedAccessGroupsPaginator,
+        DescribeVerifiedAccessInstanceLoggingConfigurationsPaginator,
+        DescribeVerifiedAccessInstancesPaginator,
+        DescribeVerifiedAccessTrustProvidersPaginator,
         DescribeVolumeStatusPaginator,
         DescribeVolumesModificationsPaginator,
         DescribeVolumesPaginator,
@@ -120,6 +126,7 @@ Usage::
         ExportTaskCancelledWaiter,
         ExportTaskCompletedWaiter,
         GetAssociatedIpv6PoolCidrsPaginator,
+        GetAwsNetworkPerformanceDataPaginator,
         GetGroupsForCapacityReservationPaginator,
         GetInstanceTypesFromInstanceRequirementsPaginator,
         GetIpamAddressHistoryPaginator,
@@ -212,6 +219,7 @@ Usage::
 
     describe_address_transfers_paginator: DescribeAddressTransfersPaginator = client.get_paginator("describe_address_transfers")
     describe_addresses_attribute_paginator: DescribeAddressesAttributePaginator = client.get_paginator("describe_addresses_attribute")
+    describe_aws_network_performance_metric_subscriptions_paginator: DescribeAwsNetworkPerformanceMetricSubscriptionsPaginator = client.get_paginator("describe_aws_network_performance_metric_subscriptions")
     describe_byoip_cidrs_paginator: DescribeByoipCidrsPaginator = client.get_paginator("describe_byoip_cidrs")
     describe_capacity_reservation_fleets_paginator: DescribeCapacityReservationFleetsPaginator = client.get_paginator("describe_capacity_reservation_fleets")
     describe_capacity_reservations_paginator: DescribeCapacityReservationsPaginator = client.get_paginator("describe_capacity_reservations")
@@ -301,6 +309,11 @@ Usage::
     describe_transit_gateway_vpc_attachments_paginator: DescribeTransitGatewayVpcAttachmentsPaginator = client.get_paginator("describe_transit_gateway_vpc_attachments")
     describe_transit_gateways_paginator: DescribeTransitGatewaysPaginator = client.get_paginator("describe_transit_gateways")
     describe_trunk_interface_associations_paginator: DescribeTrunkInterfaceAssociationsPaginator = client.get_paginator("describe_trunk_interface_associations")
+    describe_verified_access_endpoints_paginator: DescribeVerifiedAccessEndpointsPaginator = client.get_paginator("describe_verified_access_endpoints")
+    describe_verified_access_groups_paginator: DescribeVerifiedAccessGroupsPaginator = client.get_paginator("describe_verified_access_groups")
+    describe_verified_access_instance_logging_configurations_paginator: DescribeVerifiedAccessInstanceLoggingConfigurationsPaginator = client.get_paginator("describe_verified_access_instance_logging_configurations")
+    describe_verified_access_instances_paginator: DescribeVerifiedAccessInstancesPaginator = client.get_paginator("describe_verified_access_instances")
+    describe_verified_access_trust_providers_paginator: DescribeVerifiedAccessTrustProvidersPaginator = client.get_paginator("describe_verified_access_trust_providers")
     describe_volume_status_paginator: DescribeVolumeStatusPaginator = client.get_paginator("describe_volume_status")
     describe_volumes_paginator: DescribeVolumesPaginator = client.get_paginator("describe_volumes")
     describe_volumes_modifications_paginator: DescribeVolumesModificationsPaginator = client.get_paginator("describe_volumes_modifications")
@@ -314,6 +327,7 @@ Usage::
     describe_vpc_peering_connections_paginator: DescribeVpcPeeringConnectionsPaginator = client.get_paginator("describe_vpc_peering_connections")
     describe_vpcs_paginator: DescribeVpcsPaginator = client.get_paginator("describe_vpcs")
     get_associated_ipv6_pool_cidrs_paginator: GetAssociatedIpv6PoolCidrsPaginator = client.get_paginator("get_associated_ipv6_pool_cidrs")
+    get_aws_network_performance_data_paginator: GetAwsNetworkPerformanceDataPaginator = client.get_paginator("get_aws_network_performance_data")
     get_groups_for_capacity_reservation_paginator: GetGroupsForCapacityReservationPaginator = client.get_paginator("get_groups_for_capacity_reservation")
     get_instance_types_from_instance_requirements_paginator: GetInstanceTypesFromInstanceRequirementsPaginator = client.get_paginator("get_instance_types_from_instance_requirements")
     get_ipam_address_history_paginator: GetIpamAddressHistoryPaginator = client.get_paginator("get_ipam_address_history")
@@ -340,6 +354,7 @@ from .client import EC2Client
 from .paginator import (
     DescribeAddressesAttributePaginator,
     DescribeAddressTransfersPaginator,
+    DescribeAwsNetworkPerformanceMetricSubscriptionsPaginator,
     DescribeByoipCidrsPaginator,
     DescribeCapacityReservationFleetsPaginator,
     DescribeCapacityReservationsPaginator,
@@ -429,6 +444,11 @@ from .paginator import (
     DescribeTransitGatewaysPaginator,
     DescribeTransitGatewayVpcAttachmentsPaginator,
     DescribeTrunkInterfaceAssociationsPaginator,
+    DescribeVerifiedAccessEndpointsPaginator,
+    DescribeVerifiedAccessGroupsPaginator,
+    DescribeVerifiedAccessInstanceLoggingConfigurationsPaginator,
+    DescribeVerifiedAccessInstancesPaginator,
+    DescribeVerifiedAccessTrustProvidersPaginator,
     DescribeVolumesModificationsPaginator,
     DescribeVolumesPaginator,
     DescribeVolumeStatusPaginator,
@@ -442,6 +462,7 @@ from .paginator import (
     DescribeVpcPeeringConnectionsPaginator,
     DescribeVpcsPaginator,
     GetAssociatedIpv6PoolCidrsPaginator,
+    GetAwsNetworkPerformanceDataPaginator,
     GetGroupsForCapacityReservationPaginator,
     GetInstanceTypesFromInstanceRequirementsPaginator,
     GetIpamAddressHistoryPaginator,
@@ -516,6 +537,7 @@ __all__ = (
     "CustomerGatewayAvailableWaiter",
     "DescribeAddressTransfersPaginator",
     "DescribeAddressesAttributePaginator",
+    "DescribeAwsNetworkPerformanceMetricSubscriptionsPaginator",
     "DescribeByoipCidrsPaginator",
     "DescribeCapacityReservationFleetsPaginator",
     "DescribeCapacityReservationsPaginator",
@@ -605,6 +627,11 @@ __all__ = (
     "DescribeTransitGatewayVpcAttachmentsPaginator",
     "DescribeTransitGatewaysPaginator",
     "DescribeTrunkInterfaceAssociationsPaginator",
+    "DescribeVerifiedAccessEndpointsPaginator",
+    "DescribeVerifiedAccessGroupsPaginator",
+    "DescribeVerifiedAccessInstanceLoggingConfigurationsPaginator",
+    "DescribeVerifiedAccessInstancesPaginator",
+    "DescribeVerifiedAccessTrustProvidersPaginator",
     "DescribeVolumeStatusPaginator",
     "DescribeVolumesModificationsPaginator",
     "DescribeVolumesPaginator",
@@ -622,6 +649,7 @@ __all__ = (
     "ExportTaskCancelledWaiter",
     "ExportTaskCompletedWaiter",
     "GetAssociatedIpv6PoolCidrsPaginator",
+    "GetAwsNetworkPerformanceDataPaginator",
     "GetGroupsForCapacityReservationPaginator",
     "GetInstanceTypesFromInstanceRequirementsPaginator",
     "GetIpamAddressHistoryPaginator",
