@@ -89,6 +89,7 @@ __all__ = (
     "DeleteQueuedReservedInstancesErrorCodeType",
     "DescribeAddressTransfersPaginatorName",
     "DescribeAddressesAttributePaginatorName",
+    "DescribeAwsNetworkPerformanceMetricSubscriptionsPaginatorName",
     "DescribeByoipCidrsPaginatorName",
     "DescribeCapacityReservationFleetsPaginatorName",
     "DescribeCapacityReservationsPaginatorName",
@@ -178,6 +179,11 @@ __all__ = (
     "DescribeTransitGatewayVpcAttachmentsPaginatorName",
     "DescribeTransitGatewaysPaginatorName",
     "DescribeTrunkInterfaceAssociationsPaginatorName",
+    "DescribeVerifiedAccessEndpointsPaginatorName",
+    "DescribeVerifiedAccessGroupsPaginatorName",
+    "DescribeVerifiedAccessInstanceLoggingConfigurationsPaginatorName",
+    "DescribeVerifiedAccessInstancesPaginatorName",
+    "DescribeVerifiedAccessTrustProvidersPaginatorName",
     "DescribeVolumeStatusPaginatorName",
     "DescribeVolumesModificationsPaginatorName",
     "DescribeVolumesPaginatorName",
@@ -191,6 +197,7 @@ __all__ = (
     "DescribeVpcPeeringConnectionsPaginatorName",
     "DescribeVpcsPaginatorName",
     "DestinationFileFormatType",
+    "DeviceTrustProviderTypeType",
     "DeviceTypeType",
     "DiskImageFormatType",
     "DiskTypeType",
@@ -234,6 +241,7 @@ __all__ = (
     "GatewayAssociationStateType",
     "GatewayTypeType",
     "GetAssociatedIpv6PoolCidrsPaginatorName",
+    "GetAwsNetworkPerformanceDataPaginatorName",
     "GetGroupsForCapacityReservationPaginatorName",
     "GetInstanceTypesFromInstanceRequirementsPaginatorName",
     "GetIpamAddressHistoryPaginatorName",
@@ -326,6 +334,7 @@ __all__ = (
     "LogDestinationTypeType",
     "MarketTypeType",
     "MembershipTypeType",
+    "MetricTypeType",
     "ModifyAvailabilityZoneOptInStatusType",
     "MonitoringStateType",
     "MoveStatusType",
@@ -347,6 +356,7 @@ __all__ = (
     "PasswordDataAvailableWaiterName",
     "PayerResponsibilityType",
     "PaymentOptionType",
+    "PeriodTypeType",
     "PermissionGroupType",
     "PlacementGroupStateType",
     "PlacementGroupStrategyType",
@@ -392,6 +402,7 @@ __all__ = (
     "SpreadLevelType",
     "StateType",
     "StaticSourcesSupportValueType",
+    "StatisticTypeType",
     "StatusNameType",
     "StatusType",
     "StatusTypeType",
@@ -431,10 +442,17 @@ __all__ = (
     "TransitGatewayRouteTypeType",
     "TransitGatewayStateType",
     "TransportProtocolType",
+    "TrustProviderTypeType",
     "TunnelInsideIpVersionType",
     "UnlimitedSupportedInstanceFamilyType",
     "UnsuccessfulInstanceCreditSpecificationErrorCodeType",
     "UsageClassTypeType",
+    "UserTrustProviderTypeType",
+    "VerifiedAccessEndpointAttachmentTypeType",
+    "VerifiedAccessEndpointProtocolType",
+    "VerifiedAccessEndpointStatusCodeType",
+    "VerifiedAccessEndpointTypeType",
+    "VerifiedAccessLogDeliveryStatusCodeType",
     "VirtualizationTypeType",
     "VolumeAttachmentStateType",
     "VolumeAttributeNameType",
@@ -619,6 +637,9 @@ DeleteQueuedReservedInstancesErrorCodeType = Literal[
 ]
 DescribeAddressTransfersPaginatorName = Literal["describe_address_transfers"]
 DescribeAddressesAttributePaginatorName = Literal["describe_addresses_attribute"]
+DescribeAwsNetworkPerformanceMetricSubscriptionsPaginatorName = Literal[
+    "describe_aws_network_performance_metric_subscriptions"
+]
 DescribeByoipCidrsPaginatorName = Literal["describe_byoip_cidrs"]
 DescribeCapacityReservationFleetsPaginatorName = Literal["describe_capacity_reservation_fleets"]
 DescribeCapacityReservationsPaginatorName = Literal["describe_capacity_reservations"]
@@ -738,6 +759,15 @@ DescribeTransitGatewayVpcAttachmentsPaginatorName = Literal[
 ]
 DescribeTransitGatewaysPaginatorName = Literal["describe_transit_gateways"]
 DescribeTrunkInterfaceAssociationsPaginatorName = Literal["describe_trunk_interface_associations"]
+DescribeVerifiedAccessEndpointsPaginatorName = Literal["describe_verified_access_endpoints"]
+DescribeVerifiedAccessGroupsPaginatorName = Literal["describe_verified_access_groups"]
+DescribeVerifiedAccessInstanceLoggingConfigurationsPaginatorName = Literal[
+    "describe_verified_access_instance_logging_configurations"
+]
+DescribeVerifiedAccessInstancesPaginatorName = Literal["describe_verified_access_instances"]
+DescribeVerifiedAccessTrustProvidersPaginatorName = Literal[
+    "describe_verified_access_trust_providers"
+]
 DescribeVolumeStatusPaginatorName = Literal["describe_volume_status"]
 DescribeVolumesModificationsPaginatorName = Literal["describe_volumes_modifications"]
 DescribeVolumesPaginatorName = Literal["describe_volumes"]
@@ -757,6 +787,7 @@ DescribeVpcEndpointsPaginatorName = Literal["describe_vpc_endpoints"]
 DescribeVpcPeeringConnectionsPaginatorName = Literal["describe_vpc_peering_connections"]
 DescribeVpcsPaginatorName = Literal["describe_vpcs"]
 DestinationFileFormatType = Literal["parquet", "plain-text"]
+DeviceTrustProviderTypeType = Literal["crowdstrike", "jamf"]
 DeviceTypeType = Literal["ebs", "instance-store"]
 DiskImageFormatType = Literal["RAW", "VHD", "VMDK"]
 DiskTypeType = Literal["hdd", "ssd"]
@@ -820,6 +851,7 @@ GatewayAssociationStateType = Literal[
 ]
 GatewayTypeType = Literal["ipsec.1"]
 GetAssociatedIpv6PoolCidrsPaginatorName = Literal["get_associated_ipv6_pool_cidrs"]
+GetAwsNetworkPerformanceDataPaginatorName = Literal["get_aws_network_performance_data"]
 GetGroupsForCapacityReservationPaginatorName = Literal["get_groups_for_capacity_reservation"]
 GetInstanceTypesFromInstanceRequirementsPaginatorName = Literal[
     "get_instance_types_from_instance_requirements"
@@ -1105,6 +1137,7 @@ InstanceTypeType = Literal[
     "h1.8xlarge",
     "hi1.4xlarge",
     "hpc6a.48xlarge",
+    "hpc6id.32xlarge",
     "hs1.8xlarge",
     "i2.2xlarge",
     "i2.4xlarge",
@@ -1593,6 +1626,7 @@ LocationTypeType = Literal["availability-zone", "availability-zone-id", "region"
 LogDestinationTypeType = Literal["cloud-watch-logs", "kinesis-data-firehose", "s3"]
 MarketTypeType = Literal["spot"]
 MembershipTypeType = Literal["igmp", "static"]
+MetricTypeType = Literal["aggregate-latency"]
 ModifyAvailabilityZoneOptInStatusType = Literal["not-opted-in", "opted-in"]
 MonitoringStateType = Literal["disabled", "disabling", "enabled", "pending"]
 MoveStatusType = Literal["movingToVpc", "restoringToClassic"]
@@ -1639,6 +1673,9 @@ PartitionLoadFrequencyType = Literal["daily", "monthly", "none", "weekly"]
 PasswordDataAvailableWaiterName = Literal["password_data_available"]
 PayerResponsibilityType = Literal["ServiceOwner"]
 PaymentOptionType = Literal["AllUpfront", "NoUpfront", "PartialUpfront"]
+PeriodTypeType = Literal[
+    "fifteen-minutes", "five-minutes", "one-day", "one-hour", "one-week", "three-hours"
+]
 PermissionGroupType = Literal["all"]
 PlacementGroupStateType = Literal["available", "deleted", "deleting", "pending"]
 PlacementGroupStrategyType = Literal["cluster", "partition", "spread"]
@@ -1754,6 +1791,11 @@ ResourceTypeType = Literal[
     "transit-gateway-policy-table",
     "transit-gateway-route-table",
     "transit-gateway-route-table-announcement",
+    "verified-access-endpoint",
+    "verified-access-group",
+    "verified-access-instance",
+    "verified-access-policy",
+    "verified-access-trust-provider",
     "volume",
     "vpc",
     "vpc-endpoint",
@@ -1810,6 +1852,7 @@ StateType = Literal[
     "Rejected",
 ]
 StaticSourcesSupportValueType = Literal["disable", "enable"]
+StatisticTypeType = Literal["p50"]
 StatusNameType = Literal["reachability"]
 StatusType = Literal["InClassic", "InVpc", "MoveInProgress"]
 StatusTypeType = Literal["failed", "initializing", "insufficient-data", "passed"]
@@ -1895,6 +1938,7 @@ TransitGatewayRouteTableStateType = Literal["available", "deleted", "deleting",
 TransitGatewayRouteTypeType = Literal["propagated", "static"]
 TransitGatewayStateType = Literal["available", "deleted", "deleting", "modifying", "pending"]
 TransportProtocolType = Literal["tcp", "udp"]
+TrustProviderTypeType = Literal["device", "user"]
 TunnelInsideIpVersionType = Literal["ipv4", "ipv6"]
 UnlimitedSupportedInstanceFamilyType = Literal["t2", "t3", "t3a", "t4g"]
 UnsuccessfulInstanceCreditSpecificationErrorCodeType = Literal[
@@ -1904,6 +1948,14 @@ UnsuccessfulInstanceCreditSpecificationErrorCodeType = Literal[
     "InvalidInstanceID.NotFound",
 ]
 UsageClassTypeType = Literal["on-demand", "spot"]
+UserTrustProviderTypeType = Literal["iam-identity-center", "oidc"]
+VerifiedAccessEndpointAttachmentTypeType = Literal["vpc"]
+VerifiedAccessEndpointProtocolType = Literal["http", "https"]
+VerifiedAccessEndpointStatusCodeType = Literal[
+    "active", "deleted", "deleting", "pending", "updating"
+]
+VerifiedAccessEndpointTypeType = Literal["load-balancer", "network-interface"]
+VerifiedAccessLogDeliveryStatusCodeType = Literal["failed", "success"]
 VirtualizationTypeType = Literal["hvm", "paravirtual"]
 VolumeAttachmentStateType = Literal["attached", "attaching", "busy", "detached", "detaching"]
 VolumeAttributeNameType = Literal["autoEnableIO", "productCodes"]
@@ -1972,6 +2024,7 @@ ServiceName = Literal[
     "apprunner",
     "appstream",
     "appsync",
+    "arc-zonal-shift",
     "athena",
     "auditmanager",
     "autoscaling",
@@ -2168,7 +2221,10 @@ ServiceName = Literal[
     "network-firewall",
     "networkmanager",
     "nimble",
+    "oam",
+    "omics",
     "opensearch",
+    "opensearchserverless",
     "opsworks",
     "opsworkscm",
     "organizations",
@@ -2224,6 +2280,7 @@ ServiceName = Literal[
     "sdb",
     "secretsmanager",
     "securityhub",
+    "securitylake",
     "serverlessrepo",
     "service-quotas",
     "servicecatalog",
@@ -2233,6 +2290,7 @@ ServiceName = Literal[
     "sesv2",
     "shield",
     "signer",
+    "simspaceweaver",
     "sms",
     "sms-voice",
     "snow-device-management",
@@ -2288,6 +2346,7 @@ ResourceServiceName = Literal[
 PaginatorName = Literal[
     "describe_address_transfers",
     "describe_addresses_attribute",
+    "describe_aws_network_performance_metric_subscriptions",
     "describe_byoip_cidrs",
     "describe_capacity_reservation_fleets",
     "describe_capacity_reservations",
@@ -2377,6 +2436,11 @@ PaginatorName = Literal[
     "describe_transit_gateway_vpc_attachments",
     "describe_transit_gateways",
     "describe_trunk_interface_associations",
+    "describe_verified_access_endpoints",
+    "describe_verified_access_groups",
+    "describe_verified_access_instance_logging_configurations",
+    "describe_verified_access_instances",
+    "describe_verified_access_trust_providers",
     "describe_volume_status",
     "describe_volumes",
     "describe_volumes_modifications",
@@ -2390,6 +2454,7 @@ PaginatorName = Literal[
     "describe_vpc_peering_connections",
     "describe_vpcs",
     "get_associated_ipv6_pool_cidrs",
+    "get_aws_network_performance_data",
     "get_groups_for_capacity_reservation",
     "get_instance_types_from_instance_requirements",
     "get_ipam_address_history",
@@ -2454,6 +2519,7 @@ RegionName = Literal[
     "ap-northeast-2",
     "ap-northeast-3",
     "ap-south-1",
+    "ap-south-2",
     "ap-southeast-1",
     "ap-southeast-2",
     "ap-southeast-3",
